@@ -4,15 +4,20 @@ Sentence objects from an iterator that returns CoNLL source lines. This logic
 can then be used in the Conll class or in pyconll.load.
 """
 
-from pyconll.unit import Sentence
+from typing import Iterable, Iterator
+
+from pyconll.exception import ParseError
+from pyconll.unit.sentence import Sentence
 
 
-def _create_sentence(sent_lines):
+def _create_sentence(sent_lines: Iterable[str], line_num: int) -> Sentence:
     """
     Creates a Sentence object given the current state of the source iteration.
 
     Args:
         sent_lines: An iterable of the lines that make up the source.
+        line_num: The current line number the sentence starts at, for logging
+            purposes.
 
     Returns:
         The created Sentence.
@@ -21,12 +26,16 @@ def _create_sentence(sent_lines):
         ParseError: If the sentence source is not valid.
     """
     sent_source = '\n'.join(sent_lines)
-    sentence = Sentence(sent_source)
+    try:
+        sentence = Sentence(sent_source)
+    except ParseError as err:
+        raise ParseError(
+            f'Failed to create sentence at line {line_num}') from err
 
     return sentence
 
 
-def iter_sentences(lines_it):
+def iter_sentences(lines_it: Iterable[str]) -> Iterator[Sentence]:
     """
     Iterate over the constructed sentences in the given lines.
 
@@ -42,19 +51,22 @@ def iter_sentences(lines_it):
         ValueError: If there is an error constructing the Sentence.
     """
     sent_lines = []
-    for line in lines_it:
+    last_empty_line = -1
+    for i, line in enumerate(lines_it):
         line = line.strip()
 
         # Collect all lines until there is a blank line. Then all the
         # collected lines were between blank lines and are a sentence.
         if line:
             sent_lines.append(line)
-        elif sent_lines:
-            sentence = _create_sentence(sent_lines)
-            sent_lines.clear()
+        else:
+            if sent_lines:
+                sentence = _create_sentence(sent_lines, last_empty_line + 2)
+                sent_lines.clear()
+                yield sentence
 
-            yield sentence
+            last_empty_line = i
 
     if sent_lines:
-        sentence = _create_sentence(sent_lines)
+        sentence = _create_sentence(sent_lines, last_empty_line)
         yield sentence
