@@ -4,9 +4,10 @@ Defines the Sentence type and the associated parsing and output logic.
 
 from collections import OrderedDict
 import re
-from typing import ClassVar, Dict, Iterator, List, Optional, Sequence, overload
+from typing import ClassVar, Iterator, Optional, Sequence, overload
 
 from pyconll.conllable import Conllable
+from pyconll.exception import FormatError, ParseError
 from pyconll.tree._treebuilder import TreeBuilder
 from pyconll.tree.tree import Tree
 from pyconll.unit.token import Token
@@ -61,10 +62,10 @@ class Sentence(Sequence[Token], Conllable):
         lines = source.split('\n')
 
         self._meta: OrderedDict[str, Optional[str]] = OrderedDict()  # pylint: disable=E1136
-        self._tokens: List[Token] = []
-        self._ids_to_indexes: Dict[str, int] = {}
+        self._tokens: list[Token] = []
+        self._ids_to_indexes: dict[str, int] = {}
 
-        for line in lines:
+        for i, line in enumerate(lines):
             if line:
                 if line[0] == Sentence.COMMENT_MARKER:
                     kv_match = re.match(Sentence.KEY_VALUE_COMMENT_PATTERN,
@@ -81,7 +82,13 @@ class Sentence(Sequence[Token], Conllable):
                             k = singleton_match.group(1)
                             self._meta[k] = None
                 else:
-                    token = Token(line)
+                    try:
+                        token = Token(line)
+                    except ParseError as err:
+                        raise ParseError(
+                            f'Error creating token on line {i} for the current sentence'
+                        ) from err
+
                     self._tokens.append(token)
 
                     if token.id is not None:
@@ -163,7 +170,7 @@ class Sentence(Sequence[Token], Conllable):
                 singleton, this field can be ignored or set to None.
         """
         if key == Sentence.TEXT_KEY:
-            raise ValueError('Key cannot be {}'.format(Sentence.TEXT_KEY))
+            raise ValueError(f'Key cannot be {Sentence.TEXT_KEY}')
 
         self._meta[key] = value
 
@@ -179,7 +186,7 @@ class Sentence(Sequence[Token], Conllable):
             ValueError: If the text key is provided, regardless of presence.
         """
         if key == Sentence.TEXT_KEY:
-            raise ValueError('Key cannot be {}'.format(Sentence.TEXT_KEY))
+            raise ValueError(f'Key cannot be {Sentence.TEXT_KEY}')
 
         del self._meta[key]
 
@@ -205,7 +212,7 @@ class Sentence(Sequence[Token], Conllable):
             ValueError: If the sentence can not be made into a tree because a
                 token has an empty head value or if there is no root token.
         """
-        children_tokens: Dict[str, List[Token]] = {}
+        children_tokens: dict[str, list[Token]] = {}
 
         for token in self:
             if token.head is not None:
@@ -213,10 +220,10 @@ class Sentence(Sequence[Token], Conllable):
                     children_tokens[token.head].append(token)
                 except KeyError:
                     children_tokens[token.head] = [token]
-            elif not token.is_multiword():
+            elif not (token.is_multiword() or token.is_empty_node()):
                 raise ValueError(
-                    'The current sentence is not fully defined as a tree and ' \
-                    'has a token with an empty head at {}'.format(token.id))
+                    'The current sentence is not fully defined as a tree and has a token with an '
+                    f'empty head at {token.id}')
 
         builder: TreeBuilder[Token] = TreeBuilder()
         if '0' in children_tokens:
@@ -237,7 +244,7 @@ class Sentence(Sequence[Token], Conllable):
     @staticmethod
     def _create_tree_helper(builder: TreeBuilder, sentence: 'Sentence',
                             root: Token,
-                            children_tokens: Dict[str, List[Token]]) -> None:
+                            children_tokens: dict[str, list[Token]]) -> None:
         """
         Method to create a tree from a sentence given the root token.
 
@@ -267,19 +274,27 @@ class Sentence(Sequence[Token], Conllable):
 
         Returns:
             A string representing the Sentence in CoNLL-U format.
+
+        Raises:
+            FormatError: If the Sentence or underlying Tokens can not be
+                converted to the CoNLL format.
         """
         lines = []
         for meta in self._meta.items():
             if meta[1] is not None:
-                line = '{} {} = {}'.format(Sentence.COMMENT_MARKER, meta[0],
-                                           meta[1])
+                line = f'{Sentence.COMMENT_MARKER} {meta[0]} = {meta[1]}'
             else:
-                line = '{} {}'.format(Sentence.COMMENT_MARKER, meta[0])
+                line = f'{Sentence.COMMENT_MARKER} {meta[0]}'
 
             lines.append(line)
 
         for token in self._tokens:
-            lines.append(token.conll())
+            try:
+                lines.append(token.conll())
+            except FormatError as err:
+                raise FormatError(
+                    f'Error serializing sentence with id {self.id} on token \'{token.id}\'.'
+                ) from err
 
         return '\n'.join(lines)
 
@@ -288,8 +303,7 @@ class Sentence(Sequence[Token], Conllable):
         Iterate through all the tokens in the Sentence including multiword
         tokens.
         """
-        for token in self._tokens:
-            yield token
+        yield from self._tokens
 
     @overload
     def __getitem__(self, key: str) -> Token:
